@@ -1,7 +1,7 @@
 /**************************************************************************
  *                                                                        *
  *  SPRINT: Simple Parallel R INTerface                                   *
- *  Copyright  2008,2009 The University of Edinburgh                     *
+ *  Copyright ? 2008,2009 The University of Edinburgh                     *
  *                                                                        *
  *  This program is free software: you can redistribute it and/or modify  *
  *  it under the terms of the GNU General Public License as published by  *
@@ -33,14 +33,14 @@
  */
 
 extern int test(int n,...);
-extern int svm_call(int n,...);
+//extern int svm_call(int n,...);
 extern int correlation(int n,...);
 extern int permutation(int n,...);
 extern int pamedoids(int n,...);
 extern int apply(int n,...);
 extern int random_forest_driver(int,...);
 extern int boot(int,...);
-extern int hamming(int,...);
+extern int stringDist(int,...);
 extern int init_rng_worker(int n, ...);
 extern int reset_rng_worker(int n, ...);
 extern int boot_rank_product(int n, ...);
@@ -63,14 +63,14 @@ int voidCommand(int n,...)
  **/
 
 commandFunction commandLUT[] = {voidCommand,
-				svm_call,
+//				svm_call,
                                 correlation,
                                 permutation,
                                 pamedoids,
                                 apply,
                                 random_forest_driver,
                                 boot,
-                                hamming,
+                                stringDist,
                                 test,
                                 init_rng_worker,
                                 reset_rng_worker,
